package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(M``````````0```````
M`,&(``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*B`````````J(``
M```````0``````$````&````````L`````````"P`````````+``````````
M$(`````````@L````````!```````@````8```````"P(````````+`@````
M````L"`````````!P`````````'```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````H?0```````"A]````````*'T`````````-P`````````W```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+``````````L```````
M``"P`````````!``````````$````````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`)7(P[HOGS'J<?H6Q^@I`]&B?YYP````$````$```
M``%'3E4```````````,````"```````````````1````1`````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND$0@(@`````````1````$<```!*
M````2P```%(```!3````5`````````!6````5P```%@```!9````6@```%P`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5"Y<Z
M#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````````
M`P``"P```````!DH``````````````-Q$@``````````````````````````
M``(4$@````````````````````````````",$0``````````````````````
M``````&:$@````````````````````````````*J$@``````````````````
M``````````#A$0````````````````````````````&,$@``````````````
M``````````````'[$@````````````````````````````"]$@``````````
M``````````````````&W$@````````````````````````````*4$@``````
M``````````````````````&A$@`````````````````````````````!(```
M``````````````````````````'T$@````````````````````````````!G
M$@````````````````````````````*'$@``````````````````````````
M``#&$@````````````````````````````)&$@``````````````````````
M``````&%$@````````````````````````````*:$@``````````````````
M``````````%+$@````````````````````````````%A$@``````````````
M``````````````"4$@`````````````````````````````0(```````````
M``````````````````(L$@````````````````````````````$L$@``````
M``````````````````````"*$0````````````````````````````$U$@``
M```````````````````````````L(`````````````````````````````"=
M$@````````````````````````````(>$@``````````````````````````
M``%9$@````````````````````````````$`$@``````````````````````
M``````%^$@````````````````````````````'*$@``````````````````
M``````````$;$@````````````````````````````(W$@``````````````
M``````````````"S$@````````````````````````````!8(@``````````
M``````````````````):$@````````````````````````````)/$@``````
M``````````````````````$\$@````````````````````````````)4$@``
M``````````````````````````%I$@````````````````````````````(&
M$@````````````````````````````++$@``````````````````````````
M``!Y$@````````````````````````````%W$@``````````````````````
M``````)R$@````````````````````````````"<$@``````````````````
M``````````#:$@````````````````````````````#L$@``````````````
M``````````````*V$@````````````````````````````*/$@``````````
M``````````````````'H$@````````````````````````````(9$@``````
M``````````````````````*`$@````````````````````````````';$0``
M``````````````````````````"D$@````````````````````````````#,
M$@````````````````````````````$0$@``````````````````````````
M``"K$@````````````````````````````&H$@``````````````````````
M``````!&$@````````````````````````````%P$@``````````````````
M``````````)K$0````````````````````````````-Z$@``#0```````%(@
M`````````0H```//$@``#0```````%7`````````"9P```!3$@``#0``````
M`""``````````DX```+Q$@``#0```````$3P``````````8```,/$@``#0``
M`````%]@`````````H````/U$@``#0```````$4``````````KX```.U$```
M%P```````,"```````````````,"$@``#0```````$?``````````$0```,E
M$@``#0```````$]``````````(P```.&$0``#P```````&*$``````````0`
M``.B$@``#0```````%,P`````````3````.M$@``#0```````$.P````````
M`#P```/*$```%P```````-"P``````````````/C$@``#0```````%``````
M`````:0```.5$```%@```````,````````````````-)$@``#0```````$@0
M`````````6X```/<$```%@```````,"```````````````0"$0``%@``````
M`,!X``````````@```.;$@``#0```````"+0``````````````/!$@``#0``
M`````%&P`````````&P```.7(```%@```````,````````````````-?$@``
M#0```````$_0`````````"P```,S$@``#0```````$/P`````````/0```-5
M$@``#0```````%1@`````````50```0,$@``#0```````$F`````````!;(`
M7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C7W-T87)T7VUA:6X`7U]C
M>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I
M;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E
M861D:7(V-`!C;&]S961I<@!R;61I<@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!0
M3%]T:')?:V5Y`'!T:')E861?9V5T<W!E8VEF:6,`8F]O=%]$>6YA3&]A9&5R
M`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!M96UC:'(`
M4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!R96%L;&]C`&UE;6UO=F4`
M9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O:P!?7W-T<FYC<'E?
M8VAK`&=E='5I9`!S=')S='(`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E
M`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L
M7W)U;@!E>&ET`&UK9&ER`%]?97)R;F]?;&]C871I;VX`<W1D97)R`%]?9G!R
M:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`<F5A9`!C;&]S90!097)L7V=V7V9E
M=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M
M9U]S970`;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E
M>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N
M=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA
M7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN
M:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D
M871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR``````````(``0`"
M``(``0`!``,``0`"``$``@`"``$``@`$``(``@`!``(``0`!``(``@`!``$`
M`@`"``(``0`%``$``@`!``(``0`!``$``@`"``(``@`!``(``@`!``$`!@`"
M``8`!0`"``<``0`"``$``@`"``$``@`&``$``@`!``<``@`"``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!
M``8```+G````$``````&EI&T````!P``!!D````0#6EI%`````8```0D````
M$`:6D;,````%```$+@```!`):1ER````!```!#D````0"6D9=`````,```1%
M````$`UI:1(````"```$40````````````"ST``````````,````````7V``
M``````"T"``````````,````````P'@```````"T&``````````,````````
M((````````#`"``````````,````````P`@```````#`&``````````,````
M````H<````````#`(``````````,````````8N````````#`,``````````,
M````````8X````````#`.``````````,````````8X0```````#`0```````
M```,````````H;0```````#`2``````````,````````8N8```````#`4```
M```````,````````H;P```````#`8``````````,````````H:0```````#`
M:``````````,````````H:H```````#`>``````````,````````94X`````
M``"SL`````0````*``````````````````"SN`````<````*````````````
M``````"SP`````L````*``````````````````"SR`````X````*````````
M``````````"SV````!D````*``````````````````"SX````!X````*````
M``````````````"SZ````"(````*``````````````````"S\````"0````*
M``````````````````"S^````"@````*``````````````````"T`````#L`
M```*``````````````````"T$````$,````*``````````````````"Q^```
M``(````+``````````````````"R``````,````+``````````````````"R
M"`````4````+``````````````````"R$`````8````+````````````````
M``"R&`````@````+``````````````````"R(`````D````+````````````
M``````"R*`````H````+``````````````````"R,`````P````+````````
M``````````"R.`````T````+``````````````````"R0`````\````+````
M``````````````"R2````!`````+``````````````````"R4````!$````+
M``````````````````"R6````!(````+``````````````````"R8````!,`
M```+``````````````````"R:````!0````+``````````````````"R<```
M`!4````+``````````````````"R>````!8````+``````````````````"R
M@````!<````+``````````````````"RB````!@````+````````````````
M``"RD````!H````+``````````````````"RF````!L````+````````````
M``````"RH````!T````+``````````````````"RJ````!\````+````````
M``````````"RL````"`````+``````````````````"RN````"$````+````
M``````````````"RP````",````+``````````````````"RR````"4````+
M``````````````````"RT````"8````+``````````````````"RV````"<`
M```+``````````````````"RX````"@````+``````````````````"RZ```
M`"D````+``````````````````"R\````"H````+``````````````````"R
M^````"L````+``````````````````"S`````"P````+````````````````
M``"S"````"T````+``````````````````"S$````"X````+````````````
M``````"S&````"\````+``````````````````"S(````#`````+````````
M``````````"S*````#$````+``````````````````"S,````#(````+````
M``````````````"S.````#,````+``````````````````"S0````#0````+
M``````````````````"S2````#4````+``````````````````"S4````#8`
M```+``````````````````"S6````#<````+``````````````````"S8```
M`#@````+``````````````````"S:````#D````+``````````````````"S
M<````#H````+``````````````````"S>````#P````+````````````````
M``"S@````#T````+``````````````````"SB````#X````+````````````
M``````"SD````#\````+``````````````````"SF````$`````+````````
M``````````"SH````$$````+``````````````````"SJ````$(````+````
M``````#K;_`P`"2Y!``?I_O_8.,0\```),#```!,4L`0``!-0^,0$```!+D"
M`!&GA``##>'`Y0``!83`Y0``)$GC0/$0``3K;_#0``0']`<'XQ#P.``DP!``
M`$PST@?P,!`(XQ`0$``$!_$'``<`!P#`$```3#+C$!````0'\0T0XQ`0#``4
MP/3____E`````,`0``!,)N,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!``
M`$P:XQ`0```$!_$-$.,0$`P`%,#T____Q0```##`$```3`[C$!````0'\0T0
MXQ`0#``4P/3___^U````2,`0``!,`N,0$```!`?Q#1#C$!`,`!3`]/___Z4`
M``!@P!```$OVXQ`0```$!_$-$.,0$`P`%,#T____E0```'C`$```2^KC$!``
M``0'\0T0XQ`0#``4P/3___^%````D,`0``!+WN,0$```!`?Q#1#C$!`,`!3`
M]/___W4```"HP!```$O2XQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```
M2\;C$!````0'\0T0XQ`0#``4P/3___]5````V,`0``!+NN,0$```!`?Q#1#C
M$!`,`!3`]/___T4```#PP!```$NNXQ`0```$!_$-$.,0$`P`%,#T____-0``
M`0C`$```2Z+C$!````0'\0T0XQ`0#``4P/3___\E```!(,`0``!+EN,0$```
M!`?Q#1#C$!`,`!3`]/___Q4```$XP!```$N*XQ`0```$!_$-$.,0$`P`%,#T
M____!0```5#`$```2W[C$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!+
M<N,0$```!`?Q#1#C$!`,`!3`]/___N4```&`P!```$MFXQ`0```$!_$-$.,0
M$`P`%,#T___^U0```9C`$```2UKC$!````0'\0T0XQ`0#``4P/3___[%```!
ML,`0``!+3N,0$```!`?Q#1#C$!`,`!3`]/___K4```'(P!```$M"XQ`0```$
M!_$-$.,0$`P`%,#T___^I0```>#`$```2S;C$!````0'\0T0XQ`0#``4P/3_
M__Z5```!^,`0``!+*N,0$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```$L>
MXQ`0```$!_$-$.,0$`P`%,#T___^=0```BC`$```2Q+C$!````0'\0T0XQ`0
M#``4P/3___YE```"0,`0``!+!N,0$```!`?Q#1#C$!`,`!3`]/___E4```)8
MP!```$KZXQ`0```$!_$-$.,0$`P`%,#T___^10```G#`$```2N[C$!````0'
M\0T0XQ`0#``4P/3___XU```"B,`0``!*XN,0$```!`?Q#1#C$!`,`!3`]/__
M_B4```*@P!```$K6XQ`0```$!_$-$.,0$`P`%,#T___^%0```KC`$```2LKC
M$!````0'\0T0XQ`0#``4P/3___X%```"T,`0``!*ON,0$```!`?Q#1#C$!`,
M`!3`]/___?4```+HP!```$JRXQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`
M$```2J;C$!````0'\0T0XQ`0#``4P/3___W5```#&,`0``!*FN,0$```!`?Q
M#1#C$!`,`!3`]/___<4```,PP!```$J.XQ`0```$!_$-$.,0$`P`%,#T___]
MM0```TC`$```2H+C$!````0'\0T0XQ`0#``4P/3___VE```#8,`0``!*=N,0
M$```!`?Q#1#C$!`,`!3`]/___94```-XP!```$IJXQ`0```$!_$-$.,0$`P`
M%,#T___]A0```Y#`$```2E[C$!````0'\0T0XQ`0#``4P/3___UU```#J,`0
M``!*4N,0$```!`?Q#1#C$!`,`!3`]/___64```/`P!```$I&XQ`0```$!_$-
M$.,0$`P`%,#T___]50```]C`$```2CKC$!````0'\0T0XQ`0#``4P/3___U%
M```#\,`0``!*+N,0$```!`?Q#1#C$!`,`!3`]/___34```0(P!```$HBXQ`0
M```$!_$-$.,0$`P`%,#T___])0``!"#`$```2A;C$!````0'\0T0XQ`0#``4
MP/3___T5```$.,`0``!*"N,0$```!`?Q#1#C$!`,`!3`]/___04```10P!``
M`$G^XQ`0```$!_$-$.,0$`P`%,#T___\]0``!&C`$```2?+C$!````0'\0T0
MXQ`0#``4P/3___SE```$@,`0``!)YN,0$```!`?Q#1#C$!`,`!3`]/___-4`
M``28P!```$G:XQ`0```$!_$-$.,0$`P`%,#T___\Q0``!+#`$```2<[C$!``
M``0'\0T0XQ`0#``4P/3___RU```$R,`0``!)PN,0$```!`?Q#1#C$!`,`!3`
M]/___*4```3@P!```$FVXQ`0```$!_$-$.,0$`P`%,#T___\E0``!/C`$```
M2:KC$!````0'\0T0XQ`0#``4P/3___R%```%$````````````````.MO\#``
M)+)/`+#C\/\X_W'C,/"H`"3C0/"@`"10(/"TZ[L`(``-LD\`L4%`\*#2!_#`
ML"A!,/"H02#PM,#E____K,1(``!)?\0H``!)E+D$`#3`Y0``((?$&```2925
M`!``IX0`J\2H``!):>,@H```%L#E___^\;D$`!+C(*```!:6`A1ZP.7___[G
M6*#PM)8!)'KL*@`$`-BY%``BZR(``P`-P.7___\(XS#PJ``$P!```$^DN00`
M4L0K``!/L^,@,```!.,0$```!.,@4```)%B0\+3`(```(3[C$%`0`"3C(%`(
M`"3`(```(3?C(%`8`"2GJ@`#[)P`GP%^03`P"*<(``3L2?__`-CC(#````2Y
M%``0ZQ$``P`-XR%0```DIPH``:<[``BG1O_Q[!D``P#8Q"@``$]RN10`$>L1
M``,`#4$14`#E2!````"Y%`!*IVD``,`P```.A<#E___\+!BB["@`0P!^Q"@`
M`$]709#PO,#E___^`+D$`#G`(```()K`Y0``#+;L*``Y`'S$*```3T3`Y?__
M^\_`Y?___2S5!_#`L"BY%``JIW0`3NMO\/@`!`?^P.7___S>Q"L``$\M["@`
M/0!\P.7___U5Q*@``$BTXR"@```6P.7___X\D@`J)Z?T_T/$*```3Q?`Y?__
M_&(8HJ?T_[G`$```3Q;C(!````*GA``'P.4``!?*I_3_O[D$`#G`(```("3`
MY0``#&C$*P``3P'L*/^R`'RG]/_MIQ@`!*?T_WVG*0`!P.7___U9P.7___VV
M!P=!0/`(XS#P```$IPG_\+F``/"G^_]0UP?P`/``Z^_PH``D07#PH*=I``"G
M60``P"```$B-XR`@```$P.7___Z5```'!P<'!P<'!P<'!P<'!\`0``!.L,`@
M``!.K>P2``J`9,08``!(4^P8``0`?`?Q!_X'!P<'!P<'!P<'!P<'!\`@``!.
MF,`0``!.E;D)`!+K(0`#``KK,0`_``RY"``RZS,``0`*[#@`#0!\Q!@``$@R
M[!@`!P!\P"```$Y\!_$'_@<'!P<'!P<'!P<'!P<'ZY_P2``DP)```$YMX_#_
M8/]QE0"0`*=T`#W`$```2!_C$!````*GA``(Q"@``$X?P.7___RRQ!@``$Y9
MP+```$8>P*```$87P"```$84N0D`LNN[``,`"J>[___L&P`5H&6G&P`!ZR$`
M`P`-XR*@```$Q!L``$X[#>+$&```3C?L&__Q0&7`Y?___WV2`9``ZY_PZ``$
M!_X'!P<'!P<'!^OO\'``)./P_V#_<>OO\1``!`?^!P<'!P<'!P<'!P<'P/3_
M__]X!P<'!P<'!P<'!^OO\'``)./P_V#_<>OO\1``!`?^!P<'!P<'!P<'!P<'
MZV_P,``DLD\`L./P_-#_<>N[`"``#;)/`+%!$/"HT@?S*+`HN00`04&@(#BG
M60`(XS"@```$ITL`$.L#`"``#.,`3_#_),`Z`````.,P3_C_)$&@H`BG5__M
MITD`0.,P$&@`!*<;``CC,!`X`(+C,!`(`(+C,!_X_X+L4R"_(5GL4R`^`5;C
M4!!X`"2G1__IXP`@&``$XX#PL``$XP#PH``DXT`@```$XU`@$``$XZ`@"``$
MXS#PJ``$X]#PN``$PHI:@GF9N0@`@,(Z6H)YF<+:6H)YF>,P("``"+D(`-7K
M:@`"``SL:@`A'E;LEB"_`%6YYY`5N8``%+F"`!6Y"``8N><`A;F``(JY@@"`
M['0@OR59['0@.@56N0@`<^LT``(`#+D(`'CL-``A'E;LAR"_`%6Y@@!CN8``
M:+F"`&FY"`!MX]#PP``$['<[OR59PMI:@GF9['@`.@56N>B0#;D(`!?KF``"
M``SL<2"_`%7LF``A'E;L$3N_)5GL%P`Z!5:Y"``6[&,@OP!5[-$[OR59N8(`
M.>R!(+\`5;GD<!.Y!``]X]#PR``$[#@`.@56PMI:@GF9N8(`%KD(`!"YZ&`-
MN0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>5KF"`)/L<2"_`%6YY(`9N00`
MG>/0\-``!.R7`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!GL8R"_`%7LT3N_
M)5GKF``"``SLF``A'E:Y@@`Y[($@OP!5N>1P$[D$`#WCT/#8``3L.``Z!5;"
MVEJ">9FY@@`6N0@`$+GH8`VY"``3[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6
MN8(`D^QQ(+\`5;GD@!FY!`"=X]#PX``$[)<`.@56PMI:@GF9N8(`%KD(`!"Y
MZ&`-N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8`"$>5KF"`#GL@2"_`%6YY'`3
MN00`/>/0\.@`!.PX`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L:2"_`%7L
MT3N_)5GK-P`"``SL-P`A'E:Y@@"3['$@OP!5N>2`&;D$`)WCT/#P``3LEP`Z
M!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``9[&,@OP!5[-$[OR59ZY@``@`,[)@`
M(1Y6N8(`.>R!(+\`5;GD<!.Y!``]X]#P^``$[#@`.@56PMI:@GF9N8(`%KD(
M`!"YZ&`-N0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>5KF"`)/L<2"_`%6Y
MY(`9N00`G>/0\0``!.R7`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!GL8R"_
M`%7LT3N_)5GKF``"``SLF``A'E:Y@@`Y[($@OP!5N>1P$[D$`#WCT/$(``3L
M.``Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&D@OP!5[-$[OR59ZS<``@`,
M[#<`(1Y6N8(`D^QQ(+\`5;GD@!FY!`"=X]#Q$``$[)<`.@56PMI:@GF9N8(`
M%KD(`!"YZ&`-N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8`"$>5KF"`#GL@2"_
M`%6YY'`3N00`/>/0\1@`!.PX`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L
M:2"_`%7LT3N_)5GK-P`"``SL-P`A'E:Y@@"3['$@OP!5N>2`&;D$`)WCT/$@
M``3LEP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``9[&,@OP!5[-$[OR59ZY@`
M`@`,[)@`(1Y6N8(`.>R!(+\`5;GD<!.Y!``]X]#Q*``$[#@`.@56PMI:@GF9
MN8(`%KD(`!"YZ&`-N0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>5KF"`)/L
M<2"_`%6YY(`9N00`G>/0\3``!.R7`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(
M`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E:Y@@`Y[($@OP!5N>1P$[D$`#WC
MT/$X``3L.``Z!5:Y@@`6N0@`$+D(`!/K-P`"``SL-P`A'E;C</%```3"VEJ"
M>9FYZ&`-[&D@OP!5PGI:@GF9N8(`D[F``)BY@@"6N0@`D+GH8`?K:``"``SL
M:``A'E;C@/%(``3L<R"_`%7"BF[9ZZ&Y@@`V[-$[OR59[-$@.@56P!H`````
MN8``,;F"`#>Y"``PXP#Q4``$N0@`G;D(`'CLV3N_)5GK@0`"``SLV2`Z!5;L
M@0`A'E:Y"``][!,[OR59[!,@.@56N>>`UL(*;MGKH;F"`-FY&@`&N1H`?;D(
M`''L%SN_)5GL%R`Z!5:SP0`A[-DBOSY9XQ#Q6``$[-D"(1Y6N00`D+GGT&BS
MS0`"N8(`8[D:`);L8R*_/EGL8P(A'E:YYV`]N8(`-[D(`)#"&F[9ZZ&Y&@`8
M[(D[OR59N1H`$^R)(#H%5K/!``BSS0`PXX#Q8``$N0@`$^PQ.[\E6>PQ(#H%
M5K/!``/C,/%H``2SS0``PHINV>NAPCINV>NAN1H`C;D:`#;LUR*_/EGLUP(A
M'E:YY]!VN8(`>;D:`(>Y"`"`[&@[OR59[&@@.@56['DBOSY9L\$`!NQY`B$>
M5NQA(K\^6;GG<)WL80(A'E:Y@@"1L\T`$+D:`#GCD/%P``2Y"``QPIINV>NA
MN>=@%[F"`!BY&@"=N1H`D>,0\7@`!.S3.[\E6>S3(#H%5L(:;MGKH;D(`)VY
M&@`7[-D[OR59['@BOSY9[-D@.@56['@"(1Y6L\$`#>.`\8``!+/-``"YYW#6
MPHINV>NAN8(`T[D:`(:Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ(#H%
M5K/!``/C,/&(``2SS0``N>=@U[F"`-G".F[9ZZ&Y&@"-N1H`-[D(`(#L>2*_
M/EGLV#N_)5GL>0(A'E;LV"`Z!5;CD/&0``2SP0`-L\T``+GG<-;"FF[9ZZ&Y
M@@#1N1H`EKD:`#WL82*_/EFY"``P[&$"(1Y6[!,[OR59[!,@.@56L\$``>,0
M\9@`!+/-``"YYV#7N8(`V,(:;MGKH;D:`)VY&@`7N0@`D.QX(K\^6>S9.[\E
M6>QX`B$>5NS9(#H%5N.`\:``!+/!``VSS0``N>=PUL**;MGKH;F"`-.Y&@"&
MN1H`'>QC(K\^6;D(`!#L8P(A'E;L,3N_)5GL,2`Z!5:SP0`#L\T``+GG8-?C
M,/&H``2Y@@#9N1H`C;D(`(#LV#N_)5GLV"`Z!5:SP0`-L\T``,(Z;MGKH;D:
M`#?L>2*_/EGL>0(A'E;CD/&P``2YYW#6N8(`T;D:`#WLT2*_/EFY"``P[-$"
M(1Y6[!,[OR59[!,@.@56L\$``>,0\;@`!+/-``#"FF[9ZZ&Y&@"6N>?09[F"
M`&BY&@"6N0@`D.QI.[\E6>QI(#H%5K/!``;C8/'```2SS0``PAINV>NAPFIN
MV>NAN1H`%[D:`&WL>"*_/EGL>`(A'E:YYW"-[-,BOSY9N8(`@^S3`B$>5KD:
M`!BY"``0[#$[OR59[#$@.@56L\$``^,P\<@`!+/-``"YY]"'PCINV>NAN8(`
MB;D:`#>Y&@!HN0@`8.QV.[\E6>QV(#H%5K/!``>SS0``[(DBOSY9XW#QT``$
M[(D"(1Y6N>>`G;F"`)&Y&@`Y[)$BOSY9N0@`,.R1`B$>5NP3.[\E6>P3(#H%
M5L)Z;MGKH;/!``&Y&@!]XQ#QV``$N>>0V+F"`-:SS0``N1H`?>S6(K\^6>S6
M`B$>5KGGT&FY@@!CPAINV>NAN1H`&+D:`!;L8R*_/EGL8P(A'E;C,/'@``2Y
M"`!P[(<@OP!5[`<[OR59[`@`.@56PCINV>NAN0@`$+D:`#FYYV`-N8(`![D:
M`#"Y!`"3XS#QZ``$['$@OP!5[!$[OR59[!<`.@56PCJ/&[S<N0@`D;D:`#WK
M&``"``RSP0`#[!@`(1Y6L\T``.S1(+\`5;GDT(:YYA`VN8``-[F!`#CLB2"_
M`%7LF3N_)5GLF``Z!5:Y"``PXP#Q\``$N0@`.>N7``(`#.R7`"$>5KGDT'FY
M@0`9N8``&+F!`!?C</'X``3""H\;O-RY&@`&PGJ/&[S<N0@`$+GHT`?L8R"_
M`%7L,SN_)5GL-@`Z!5:Y"``QZQ@``@`,[!@`(1Y6[-$@OP!5N>80>;GDT(FY
M@`!VN8$`>+D(`'#C`/(```3L@R"_`%7""H\;O-RY&@`)ZY8``@`,[)8`(1Y6
MN>30:;F!`!FY@``8N8$`%N-@\@@`!+D(`!#":H\;O-RYZ-`&[#,[OR59[#@`
M.@56N0@`-^QS(+\`5>PS.[\E6>PW`#H%5KD(`#'K&``"``SL&``A'E;LT2"_
M`%6YYA!IN>30B;F``&>Y@0!HN0@`8.,`\A``!.R#(+\`5<(*CQN\W+D:``GK
MEP`"``SLEP`A'E:YY-!YN8$`&;F``!BY@0`7XW#R&``$N0@`$,)ZCQN\W.PS
M.[\E6;GHT`?L.``Z!5:Y"``V[&,@OP!5[#,[OR59[#8`.@56N0@`,>L8``(`
M#.P8`"$>5NS1(+\`5;GF$(FYY-!YN8``AKF!`(>Y"`"`[',@OP!5XP#R(``$
M[#,[OR59[#<`.@56N0@`..N&``(`#.R&`"$>5KGDT&BY@0`8N8``%[F!`!;C
M8/(H``3""H\;O-RY&@`)PFJ/&[S<N0@`$+GHT`;LDR"_`%7L,SN_)5GL.0`Z
M!5:Y"``QZQ<``@`,[!<`(1Y6[-$@OP!5N>80:+GDT'BY@`!IN8$`9[D(`&#C
M`/(P``3L<R"_`%7""H\;O-RY&@`(ZXD``@`,[(D`(1Y6N>:`D;GDT!BY@`"7
MN8$`D>,0\C@`!+D(`)#"&H\;O-RY"``=L\$``;/-``#L,SN_)5GL-P`Z!5:Y
M"``V[&,@OP!5[#,[OR59[#8`.@56ZQ<``@`,N0@`D^P7`"$>5NS1(+\`5;GF
M$#BYY-!XN8``-KF!`#>Y"``PXP#R0``$['D@OP!5P@J/&[S<[)D[OR59L\$`
M`.R7`#H%5KD(`#GKE@`"``SLE@`A'E:YY-`)L\$`(+/-``"Y@0`9N1H`"+/!
M``"SS0`"N8``%[F!`!"SS0``[&,@OP!5XX#R2``$N0@`$,**CQN\W+GHT`CL
M,SN_)5GL-@`Z!5:Y"``QZQ<``@`,[!<`(1Y6[-$@OP!5N>80>;GDT(FY@`!V
MN8$`>+D(`'#C`/)0``3L@R"_`%7L,SN_)5GL.``Z!5;""H\;O-RY&@`)N>@P
ME^LV``(`#.PV`"$>5KGDT&.Y@0`3N8``&+F!`!;C8/)8``2Y"``0PFJ/&[S<
MN>C0!NQY(+\`5>R9.[\E6>R7`#H%5KD(`)'K&``"``SL&``A'E;LT2"_`%6Y
MYA!CN>30@[F``&>Y@0!HN0@`8.,`\F``!.R)(+\`5>R9.[\E6>R8`#H%5L(*
MCQN\W+D:``.YZ)`VZY<``@`,[)<`(1Y6N>30>;F!`!FY@``8N8$`%^-P\F@`
M!+D(`!#">H\;O-RYZ-`'[&,@OP!5[#,[OR59[#8`.@56N0@`,>L8``(`#.P8
M`"$>5NQQ(+\`5;GF$-FYY'")N8``UKF!`-BY"`#0XP#R<``$[(,@OP!5P@J/
M&[S<[#,[OR59N1H`";/!``#L.``Z!5:Y"``]ZY8``@`,[-,@OP!5[)8`(1Y6
M[&,[OR59N>:0,;GD<!FSP0`AL\T``KD$`!;C8/)X``2Y@``XN8$`,+/-``#L
M'0`Z!5;":H\;O-RY"``PN>AP!KD(`#'K&``"``SL&``A'E;L<2"_`%6YY'!I
MN>80B;F``(VY@0"&[&,[OR59[&,@.@56N0@`@+D(`(;C8/*```3K#0`"``S"
M:H\;O-RY&@!IN00`D+/!``;LG0`A'E:YY'!IP#H`````L\T``+F!`!FY@``3
MN8$`%N-@\H@`!+D(`!#":LIBP=;LV#N_)5FYZ'`&[-@@.@56ZW,``@`,N0@`
M'>QS`"$>5NQA.[\E6;D$`##L82`Z!5;CT/*0``2SP0!&L\T`!+GG<&FY@@!H
MPMK*8L'6N1H`-KD:`-FY"``PL\$`;>QH(K\^6>,`\I@`!.QH`B$>5K/-`(;L
MDSN_)5GLDR`Z!5:YYV#7P@K*8L'6N8(`T;D:``>Y&@"-N0@`B>R8.[\E6>R8
M(#H%5NQQ(K\^6;/!`"GL<0(A'E;CD/*@``2Y!``0L\T``KGG<-;"FLIBP=:Y
M@@#3N1H`EKD:`!WL8R*_/EFY"``0[&,"(1Y6[#$[OR59[#$@.@56L\$``^,P
M\J@`!+/-``"YYV#7N8(`V,(ZRF+!UKD:`)VY&@`WN0@`D.QX(K\^6>S9.[\E
M6>QX`B$>5NS9(#H%5N.`\K``!+/!``VSS0``N>=PUL**RF+!UKF"`-&Y&@"&
MN1H`/>QA(K\^6;D(`##L80(A'E;L$SN_)5GL$R`Z!5:SP0`!XQ#RN``$L\T`
M`+GG8->Y@@#9PAK*8L'6N1H`C;D:`!>Y"`"`['DBOSY9[-@[OR59['D"(1Y6
M[-@@.@56XY#RP``$L\$`#;/-``"YYW#6PIK*8L'6N8(`T[D:`):Y&@`=[&,B
MOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ(#H%5K/!``/C,/+(``2SS0``N>=@U[F"
M`-C".LIBP=:Y&@"=N1H`-[D(`)#L>"*_/EGLV3N_)5GL>`(A'E;LV2`Z!5;C
M@/+0``2SP0`-L\T``+GG<-;"BLIBP=:Y@@#1N1H`AKD:`#WL82*_/EFY"``P
M[&$"(1Y6[!,[OR59[!,@.@56L\$``>,0\M@`!+/-``"YYV#7N8(`V<(:RF+!
MUKD:`(VY&@`7N0@`@.QY(K\^6>S8.[\E6>QY`B$>5NS8(#H%5N.0\N``!+/!
M``VSS0``N>=PUL*:RF+!UKF"`-.Y&@"6N1H`'>QC(K\^6;D(`!#L8P(A'E;L
M,3N_)5GL,2`Z!5:SP0`#XS#RZ``$L\T``+GG8->Y@@#8PCK*8L'6N1H`G;D:
M`#>Y"`"0['@BOSY9[-D[OR59['@"(1Y6[-D@.@56XX#R\``$L\$`#;/-``"Y
MYW#6PHK*8L'6N8(`T;D:`(:Y&@`][&$BOSY9N0@`,.QA`B$>5NP3.[\E6>P3
M(#H%5K/!``'C$/+X``2SS0``N>=@U[F"`-G"&LIBP=:Y&@"-N1H`%[D(`(#L
M>2*_/EGLV#N_)5GL>0(A'E;LV"`Z!5;CD/,```2SP0`-L\T``+GG<-;"FLIB
MP=:Y@@#3N1H`EKD:`!WL8R*_/EFY"``0[&,"(1Y6[#$[OR59[#$@.@56L\$`
M`^,P\P@`!+/-``"YYV#7PCK*8L'6N8(`V+D:`#>Y&@"=N0@`D.QY.[\E6>QY
M(#H%5K/!``?C</,0``2SS0``[-@BOSY9PGK*8L'6[-@"(1Y6N1H`=KGGT(;L
M82*_/EFY@@"![&$"(1Y6N1H`.+D(`##L$SN_)5GL$R`Z!5:YYV"-L\$``;F"
M`(GC$/,8``2Y&@!X[(DBOSY9[(D"(1Y6N>>`EKF"`).SS0``PAK*8L'6N1H`
M';D:`!GLDR*_/EGLDP(A'E;C,/,@``2Y"`!PPCK*8L'6[-<@OP!5N0@`-.P'
M.[\E6;D:`#;L#0`Z!5:Y"``0N>>0"+D$`$"Y@@!'N00`<^PQ(+\`5;D:`'3L
M$3N_)5GL$P`Z!5:Y"``7N0@`.L`Z`````.,P(`@`),`:`````.,0(```).,P
M\*``!+D$`!CC$"`@``C`&@````#C$"`@`"2Y"``YZQT``@`,P#H`````XS`@
M&``D[!T`(1Y6N0@`%<`:`````.,0(!``)-4'\RBP**=T``;K;_-@``0'_L#E
M___Q9@<'ZV_P,``DX_#_8/]Q["@`7`!\Q!@``#P7XW`0```"IX0`4^,0(```
ME+D$`(*Y!`!CN00`DI4`(`"GA`!.[!@`##U^09"0`>,0D```E)4`D`"G=/_V
M&YCCH'````*GA``?N10`F;D$`+>Y!`!)N00`.+D$`"K`Y?__[_CL)@`)`'Y!
M&:``E3T0`*>$``]!L+`(XZ"P```"IW3_Z;D$`"KK;_#0``0'_KGI<!M!J:`!
MZQ$``P`*4!!@`+D$`"KK;_#0``0'_J>I``"Y!``JZV_PT``$!_ZGF```I_3_
MOP<'!P?KK_!0`"2R3P"PX_#^R/]QZ[L`(``-LD\`L;D$`*+2!_$PL"A!,/"@
MP.7___$.["8`(0!^&!)8(/"XISA``,`K``#P`.PC``B`=J4_H`#L(P`38':Y
M!``JISD``L#E___Q=!`2IQK__X@0`!^G]``$IQ@``-4'\3"P*+D4`"&G=``&
MZZ_QB``$!_[`Y?__\*WK;_`P`"2R3P"@X_#^P/]QZZH`(``-LD\`H=('\3B@
M*.PH``D`?+D$`&*5`"``IW0`"]4'\3B@**=T`(CK;_%P``0'_L#E___Q:+D$
M`++L*/_R`'SLACR_`%5!T/"HIWD`#[D$`"O`Y?__[^?L*`!4`'Q!D"`3E2X@
M$Z=T``:5`)`!IX3_\)4N(!.GA`!1IQD``.R(`%<`?+GI@#?G`V```#>G&P`0
MYP``,`"!IX0`#.<!8`!`!J<;`!#G```P`(&G=/_XYT``!P`AN80`1+D@`$-!
M,#`!N>(@$Z<D`#/C04_P_W&G.0``[!D\OP!5IX0`,+GI$!?G`2`3`#>G.P`0
MYP``,`"!IX0`*.<#(!-`!J?T__:Y!``KP.7__^XNN00`)L#E___NB:?T_X65
M+I`!IW3_KY4`D`*GA/^5I_3_J:<Y``^G]/^VP.7___`&IQD`#Z?T_]SG4``'
M`"&YA`!5N2``44$0$`&YXB`QIR3_\>,37_#_<;GX$"2G*@`"N10`(L#E___N
M*>.0\*``)*<Y``&Y!`"2P%```!()ITG__\#E___PFKD$`#VY!``IP.7__^[C
M["@`#?]^6!#PP*<H0`#`&P``\`#L$@`/@':Y!``IP.7___`!N00`*<#E___P
M3*?T_T"Y!``IP.7___\+I_3_]`<'!P<'!P<'!P<'!^MO\#``),2X```Z:>/P
M_UC_<>,@L```%L!@```3*L#E___OZ^,@L```%L#E___OY<1(```Z;,!0```Q
M6,`P```1N<#E___P6>,@L```%L#E___OT\!````0%N5(\*```+D$`%;`,```
M$;/`Y?__[L7K;_#8``0'_@<'!P<'!P<'ZW_P.``DX_#P`/]QXP#_^``@X_#_
M6/]QXP#PH``@LD\`@.,0\*`!<>N(`"``#;)/`(&Y!`"CT@<0`(`H09#PH+D$
M`+*Y!``YITD/_\`@```1BL#E___N,>PL`#$`?NP2__\`V+D4`'%!-_"@E0`P
M`*=T`$'L&``C`'ZY!`!'N00`*:<Y`"_`Y?__[B?L*``7`'S$&```.>/C(!``
M`!;`Y?__[VNY!`!7N00`2;D$`#O`Y?__[L*G]``2Q!@``#G/XR`0```6P.7_
M_^]7N00`2KD$`#O`Y?__[;#C$/"@`7'5!Q``@"BG=``*ZW_PX`$$!_ZY%`!R
MI_3_PL#E___N[>MO\#``)+D$`.^R3P"`X_#_0/]QI^O_^&"`X`#KB``@``VR
M3P"!N00`LKD$`*.5/3``T@?PL(`HIW0`!$&@,`&G&0``[#H\OP!5IX0`>:<I
M``^Y"0`CYP*@```WIQL`$.<``#``@:>$``SG`:``0`:G&P`0YP``,`"!IW3_
M^.<P``<`(;F$`#.Y(``R02`@`;GB(!*G)`!4XQ$_\/]Q03#PK.,0\*``)+D$
M`"O`Y?___3*Y!``R["@`2P!\IQD``.Q"/+\`5:>$`#^G*0`/N0D`).<",```
M-Z<;`!#G```P`(&GA``,YP$P`$`&IQL`$.<``#``@:=T__CG0``'`"&YA`!$
MN2``0D$@(`&YXB`2IR0`&N,@\*``!.,13_#_<>PA`03`9>.0\*P`%,1X```Y
M$NN9``,`#:?T`%>G*0`/I_3_E:<I``^G]/_/Q'@``#D"XY!P```$XQ"0```"
MIX0`W+D$`!FG:```&":G:@`!01`0".,P$````J=T__BG*@`#N10`(NLB``,`
M#<`0```_4N,0$```$J>$`)JY!``RN00`*<#E___M2.,@<```)+/!`(+L*`!]
M`'RY%`"6ZYD``P`-L\T`&%!@\*SLU@`!`-BY%`#=Z]T``P`-01T0`.5($```
M`.,@L```E+D$`!N5`+``IW0`#:?T`(M!$!`!XR`0``"4E0`0`*>$``7L)O_W
M/7ZY"0`;N10`$>,@\*``!+D$`&E!(A`"XV!P```(P.7__^P2XR!@```D["@`
M.0!\XR!P```$XQ"P``"0XSD@```$0;"P`4(0,``80>P6`!``?*?T`##C$+``
M`)!!L+`!0A`@`1A![!@`)@!\0D#PH+D$`".5/?"@03`P`:=T_^V2/2``IQD`
M`.,QH```D$(Q(`&G&P`![#;_^0!\U0?PL(`HIW0`-VB`\+CK;_#P``0'_KD$
M`".G]/_EP!```#ZRY4P0```!P.7__^N^N00`TK/!`(+L*/_D`'RY!``YN10`
MENN9``,`#;D$`$G`Y?__["OCT'```"2G]/]=IQD``*?T_X6G*0`0IV@``*?T
M_S?`Y?__[5FG&0``XR&@``"00B$P`*<;``'L)O_Y`'RG]/^W!P<'!P<'!P<'
M!P<'Z^_P<``DQ!@``#@!X_#_8/]QXR`0```6P.7__^V&Q$@``#@-P%```"[Y
MP#````]:Z^_Q$``$P/3__^WW!P<'!^MO\#``)./P\`#_<>,`__@`(./P\`#_
M<>,`__@`(./P_TC_<>,`\+``(+)/`)#C$/"P`G'KF0`@``VR3P"1X[#PKP%Q
MT@<0`)`HP.7__^S-P!````].XQ#PH``DN00`8J=)$`&G.0`!N00`*\!0```/
M.D&`\*[`Y?__[:>Y!``KN00`.*=)$`#`Y?__Z\[L)``L`'ZY!`"RIRH``;D4
M`"+`Y?__ZQ*Y!`"B["@`$`!\N10`N[D$`#BY!`!+P.7__^W401N@`)(`$`#C
M$/"P`G'5!Q``D"BG=``,N00`*NMO\.@"!`?^IZD``*?T__#`Y?__[*L'!P<'
M!P<'!P<'!P?`]/___X`'!P<'!P<'!P<'ZV_P,``DX_#P`/]QXP#_^``@X_#^
ML/]QXP#Q2``@LD\`D.,0\4@!<>N9`"``#;)/`)&Y!`""T@<0`)`HN00`H\`@
M```.T4$P\+3`Y?__^Q.G.0`ON00`LKD$`"C`Y?__['SL*``9`'S`(```#L*Y
M!``XP.7___UWN00`*.,0\4@!<=4'$`"0**=T`1CK;_&``00'_J<9``#L.#R_
M`%6GA`"<IRD`#[D)`"/G`H```#>G&P`0YP``,`"!IX0`#.<!@`!`!J<;`!#G
M```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D`'>Y!``JXZ$_\/]Q
MP.7__^M?P#````Y_P.7__^JIN00`8NPH_ZX`?*>J``%!</%(0=#PN)4`8`"G
MA`!S[+@`#P!\IP@``+D$`!:Y!``KLET`$J<4__ZGA`!3IQD``.PV/+\`5:>$
M`+&G*0`/N0D`(^<"8```-Z<;`!#G```P`(&GA``,YP%@`$`&IQL`$.<``#``
M@:=T__CG,``'`"&YA``SN2``,D$@(`&YXB`2IR0`C.-!/_#_<;D$`#;L%/__
M`-BY&``QE2\P`*=T`#:2`#``&$&Y!``VIQK__[D8`#&5+S``IX3_]:?T`">G
M*0`/I_3_<I4`L`&G=``:P#````X*IRD``,#E___J,KD$`&+L*/\W`'R5`&``
MIW3_D>RX``<`?)4NL`"GA/_FP&````WEIT@``1I*IQ@/_^Q!_R$@=N.`\*@`
M),`0```-Y>,0\*``)*<Y``&Y!``GP%````Y2ITD0`,#E___L,KD$`#VY!``G
MP.7__^I[[";_P0!^6!#PT*4O@`#`&P``\`#L$O^W8':Y!``GISD``<#E___L
M!^PF_ZT`?KD$`#?`(```#:O`Y?___&*Y!``GP.7__^J'I_3^Z*<I``^G]/]=
MP.7__^L^!P>5`"``N00`$N,P(```E`>.ISX`+T$0$`&YXH`AXS`0``"4E0`0
M``>.ISX`+T$0$`&YXH`AXS`0``"4E0`0`*=T_^D'_@<'!P<'!P<'!P<'!^PH
M`%8`?+D$`#*5`"``IX0`3Z<9``#L0CR_`%6GA`!$IRD`#[D)`"3G`C```#>G
M&P`0YP``,`"!IX0`#.<!,`!`!J<;`!#G```P`(&G=/_XYT``!P`AN80`1+D@
M`$)!("`!N>(@$J<D`!_C$4_O_W&Y"``3N>DP0>PQ`':@994O$`"G=``;XQ`?
M__]QIT?_^94O,`"GA``,P"````TJP/3__^H#IRD`#Z?T_\K`(```#1+`]/__
MZ?GL,0!6H&6YZ3!!XQ`?__]QIT<`!*?T_^*5+Q``IW3_][GI,$'C(!___W'L
M,@`L(&7L.``I_WSC$!___W&G1P`GN0D`$Z=)$`#L(0`"`-GL)``L(&7K[_!P
M`"1!0!`!X_#_8/]QIUD0`,`@```[P,#E___H;\`@```[NNOO\1``!`?^ITD`
M`:?T_]B5+Q``IX3_U+D)`!.G21``["$``@#9["3_VL!EIRD```?^[#'_NF!D
MI_3_DP<'ZZ_P4``DLD\`L./P_S#_<>N[`"``#;)/`+'`$```+!;2!_#(L"C2
M(?"F$`I!H/"@N00`.L`@```,I<#E___XV^PH`"X`?,0H```T]>,0\*``%.L1
M``,`#>,0(```".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L
M)O_X`'RY!``ZP"````QZP.7___BP[";_V`!\N00`.L`@```,=,#E___XI>PH
M`"X`?,0H```TO^,0\*``%.L1``,`#>,0(```".,@$`@`!.,@$```).PH_^,`
M?.,@$!``!$$0$`CC(!```"3L)O_X`'RY!``ZP"````Q)P.7___AZ[";_V`!\
MN00`.L`@```,0L#E___X;^PH`"X`?,0H```TB>,0\*``%.L1``,`#>,0(```
M".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L)O_X`'RY!``Z
MP"````P7P.7___A$[";_V`!\N00`.L`@```,$<#E___X.>PH`"X`?,0H```T
M4^,0\*``%.L1``,`#>,0(```".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0
M$`CC(!```"3L)O_X`'RY!``ZP"````OFP.7___@.[";_V`!\N00`.L`@```+
MW\#E___X`^PH`"X`?,0H```T'>,0\*``%.L1``,`#>,0(```".,@$`@`!.,@
M$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L)O_X`'RY!``ZP"````NTP.7_
M__?8[";_V`!\N00`.L`@```+L<#E___WS>PH`"X`?,0H```SY^,0\*``%.L1
M``,`#>,0(```".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L
M)O_X`'RY!``ZP"````N&P.7___>B[";_V`!\N00`.L`@```+4\#E___WE^PH
M`"X`?,0H```SL>,0\*``%.L1``,`#>,0(```".,@$`@`!.,@$```).PH_^,`
M?.,@$!``!$$0$`CC(!```"3L)O_X`'RY!``ZP"````LHP.7___=L[";_V`!\
MN00`.L`@```+2\#E___W8>PH`"X`?,0H```S>^,0\*``%.L1``,`#>,0(```
M".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L)O_X`'RY!``Z
MP"````L@P.7___<V[";_V`!\N00`.L`@```+&L#E___W*^PH`"X`?,0H```S
M1>,0\*``%.L1``,`#>,0(```".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0
M$`CC(!```"3L)O_X`'RY!``ZP"````KOP.7___<`[";_V`!\N00`.L`@```*
MZ<#E___V]>PH`"X`?,0H```S#^,0\*``%.L1``,`#>,0(```".,@$`@`!.,@
M$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L)O_X`'RY!``ZP"````J^P.7_
M__;*[";_V`!\N00`.L`@```*@,#E___VO^PH`"X`?,0H```RV>,0\*``%.L1
M``,`#>,0(```".,@$`@`!.,@$```).PH_^,`?.,@$!``!$$0$`CC(!```"3L
M)O_X`'RY!``ZP"````I5P.7___:4[";_V`!\N00`.L`@```*@L#E___VB;D$
M`#+L*``)`'S`(```"FW`Y?__^/:Y!``ZP"````IXP.7___9VN00`,NPH``D`
M?,`@```*=L#E___XX[D$`#K`(```"G3`Y?__]F.Y!``R["@`&P!\P"````H4
MP.7___C0P#````IZP"````HKP.7___C'U0?PR+`HIW0`)^NO\2``!`?^N00`
M.L`@```*5\#E___V/KD$`#+L*``+`'S`(```"AW`Y?__^*NG]/_;P!````I-
MU0D0`/"WIW3_TT$P\,&G]/_NP.7__^>$!P<'!P<'!P<'!P<'!P?KO_!8`"2R
M3P"PX_#_4/]QZ[L`(``-LD\`L<0M```X6]('\*BP*.PH``[_?M4'\*BP*+D4
M`"*G=``HZ[_Q"``$!_Y!,/"DP"````G<P.7___7R["@`%@!\OQ$@`*>$`!'`
M%P```#"YA``1N0,`(>PB/[\!6<0O```X+J?T_]FG*```I_3_^<#E___G-P<'
M!P?K[_!P`"3C\/]@_W'`Y?__Y/S`Y?__Y-GL*``&`'SC("````3K[_$0``0'
M_@<'!P?K;_`P`"2R3P"@X_#_0/]QZZH`(``-LD\`H;D$`&+2!_"XH"A!,/"T
MP"````G*P.7___6A["@`&@!\N00`LI4`(`"GA``3N00`-L#E___E)>PH`!P`
M?-4'\+B@**=T`&/K;_#P``0'_M4'\+B@**=T`%JY!``VP"````FCZV_P\``$
MP/3___?OIQD``.PV/+\`5:>$`$2G*0`/N0D`(^<"8```-Z<;`!#G```P`(&G
MA``,YP%@`$`&IQL`$.<``#``@:=T__CG,``'`"&YA``SN2``,D$@(`&YXB`2
MIR0`'^-!/_#_<:<I``#L.SR_`%6GA``<IQD`#[D)`!/G`;```#>G*P`0YP``
M,`"!IX0`$N<"L`!`!J?T__:G*0`/I_3_RL#E___FB:<9``^G]/_RYS``!P`A
MN80`,[D@`#%!$!`!N>(@(:<D__'C$C_P_W%!)!`"P.7__^2PX[#PJ``DP!``
M``C-XQ#PH``DN00`LL!0```)/:=)__^G.0`!P.7__^<;U0?PN*`HIW3_S+D$
M`#O`(```"17K;_#P``3`]/__]V$'!P<'!P<'!P<'!P?K[_!P`"2G*0"`X_#_
M8/]QP.7__^1ZP#%G12,!XS`@```DP#_OS:N)XS`@"``DP#^8NMS^XS`@$``D
MP#$0,E1VXS`@&``DY4@@*```Y4@@,```Y4P@>```P#_#TN'PXS`@(``DZ^_Q
M$``$!_X'!P<'ZY_P2``DLD\`D./P_U#_<>N9`"``#;)/`)&Y!`"BT@?PJ)`H
MP.7___KFXQ`@``"4N00`LI4`(`"GA``/IQX`+T$@(`&YXH"RXQ`@``"4E0`@
M`*=T__7$'0``-LWL&``6_W[L&``*`'[LJ``'`'R5`*``IW0`)]4'\*B0**=T
M`$3KG_#X``0'_D$P\*3`(```"$G`Y?__]%_L*``N`'SC$"```)3L&``H`'[L
M&``E,'[`$```-J#E3!````&G]/_6N00`*Z=)``3`,```"'+`Y?__Y'/L)O_1
M`'[5!_"HD"BG=``2N00`*NN?\/@`!,#T___TZ<`0```V?N5,$````*?T_[O`
MY?__Y8@'!P<'!P?K;_`P`"2Y!`"2XR`@*``$ZQ0``P`-N0@`$NQ1(+\`5;D$
M`(3C\/]@_W'C0)`P``2Y!`"SN3$`(:?$``2G2P`!XU"0*``DZQ@`'0`,N0@`
M%.,0D#``)$%PD#CC$)!X`!*G=``\[(P`8C]^[&C_P`#8B&``!NP6``$`V.P1
M'[D&6>RA_\``V4'1L`#KJ@`&``RGJP`!TC]P`+``N00`*4&PL$#`Y?__Z%^G
MI__VIXK_P(E@``8;AKD4`(BY!``]N00`)[D$`$C`Y?__YB]0@)!XZV_PT``$
M!_ZGJ`!`&Z$9J+D$`">Y\C"HN1@`(;D4`&JY!``[N00`1L#E___F%A@:6A"0
M>%`0D'CL%O_D0'ZY^:"HN00`*;D(`+:Y%`"*P.7__^@AI_3_H+D$`-NG]/_'
MZX_P0``DXY`P*``$N00`L^.`,#``!.PY.K\]6;D4`!-!$;`XDH`0`*<Z``'C
M\/]@_W&Y%``3N00`HD$1L#CL/`!=.'ZG2`!`N?DP).Q#`!"`=J<J___K,@`(
M`-[L-@!M`'ZY%@`BQB````!QN00`*\#E___GX-<WL#BP.$*`L'-"D+!WZQ@`
M&``,0A"P<.L8`!``#$(0L''K&0`8``Q"$+!TZX@`"``,0H"P<NL9`!``#$(0
ML'7KF0`(``Q"D+!VN00`*\#E___GMM(#H`"P!+D$`"O2`Z`$L`S2`Z`(L!32
M`Z`,L!S2`Z`0L"3KC_#@``3`]/__Y0&G2``XN?DP).Q#_[Z`=J<J___K,@`(
M`-[L-@`*`'ZY%@`BQB`````:I_3_KM?_$``0`$$0$0"G-O_[I_3_\M?_$``0
M`$$0$0"G-O_[I_3_C]<`$``0`-<`$``0``<'!P<'!P<'!P<'!^MO\#``)./@
M\`#X<>/P\`#_<>,`__@`(+DA`/ZG)/_XN00`_N/P_B#_<>,`\=@`(+)/`!#C
M,/'8"''K$0`@``VR3P`107#PS.,0\,``)+D$`)+2!S``$"C`$```-/RY!``W
MP"````9@TD?PZ!`(T@_PT!!0T@?PX!!@P.7___*;["@`"0!\N00`LI4`(`"G
M=`$>P.7__^'!P.7__^&>["@`W`!\X[`@```"IX0`UJ<9``#L.SR_`%6GA`#+
MIRD`#[D)`"/G`K```#>G&P`0YP``,`"!IX0`#.<!L`!`!J<;`!#G```P`(&G
M=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D`*;C(3_P_W'K(@`!``VG*P`!
MP.7__^'OE0"P`.-@L```E+D$`-*GA``=N00`K;D$`"JY%`!FP%````9TITG_
M_Z<Y``'`Y?__Y%9!L+`!0:"@`N-@L```E)4`L`"G=/_I0:#Q",`@```&+*?T
M``FGJP`(XR"O^/\"IX0`O;D$`#?`Y?__\A:Y!`"R["C_\@!\E0`@`*>$_^W`
MY?__\GKL*/_H`'ZY!``KP.7__^*DN00`8NPH`*``?*<9``#L-CR_`%6GA`#/
MIRD`#[D)`"/G`F```#>G&P`0YP``,`"!IX0`#.<!8`!`!J<;`!#G```P`(&G
M=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D`*KC,3_P_W&G*0``[$T\OP!5
MIX0`IZ<9``^Y"0`4YP'0```WIRL`$.<``#``@:>$`)WG`M``0`:G]/_VIRD`
M#Z?T_T.GJ```N10`&NL1``,`#>,A\-```J>$`"*Y!``WIZH``<#E___QG>PH
M_^\`?)4`(`"GA/_JP.7__^(UN00`LNPF_PT`?+D4`!KK$0`#``WC(?#0``*G
M=/_BIRD`#<"P```%M,#E___A'J=H`%.Y!`#2I_3_-,#E___[N^,0\,``!.,@
M\=@(<=4'(``0**=T`$6Y!``KZV_R$`@$P/3__^("IZ@``+D4`!KK$0`#``WC
ML?#H``*GA``DE0"P`*>$`""Y!``KIZH``<#E___QN>PH_^L`?KD$`"O`Y?__
MX>.Y!`!B[";_0@!\N10`&NL1``,`#>.Q\.@``J=T_^"G:0``IQD``.PV/+\`
M5:=T_S6G*0`/I_3_/\#E___BA*<9``^G]/]GYT``!P`AN80`1+D@`$%!$!`!
MN>(@(:<D__'C$D_P_W$:$Z<:!`2Y%`"QN00`*\#E___@IN/0\+``),`0```%
M+.,0\*@`),`0```$ON,0\*``)+D$`(*G.0`!P%````4JITG__\#E___C"[D$
M`"BG.0'`P.7__^($["8`"_]^P.7__^'.6!`@`.P6`5`1?D'0\3"Y!``HN00`
M/<#E___B8!BB["8`#0!^6!#Q2*<H0`#`&P``\`#L$@`I@';$&```+0WC4)``
M``3C(!````2Y!`!HP$````41ISD``:>Y``#`Y?__XBWC$/#```3C(/'8"''5
M!R``$"BG=/]]N00`*^MO\A`(!`?^6&#Q3,#E___?Q^QB_]5@=E@0\4BG*`'`
MP!L```'_[!+_RV!VN00`*\#E___@);D$`#>Y!`"RP"````4%P.7___!YN00`
M,NPH`-\`?.,@D```!,#E___U-KD$`&+L*`#4`'RG&0``[#8\OP!5IX0`UJ<I
M``^Y"0`CYP)@```WIQL`$.<``#``@:>$``SG`6``0`:G&P`0YP``,`"!IW3_
M^.<P``<`(;F$`#.Y(``R02`@`;GB(!*G)`"QXR$_\/]Q["P`(`-^N10`$L`P
M```$ON,1;_S_<:<(``"R70`QIQ3__J=T``_L*`&>!'ZG*O_[N10`(D$28`"5
M+Q``IX0!D\0=```R9^P8`7+_?NP8`*P`?L`P```$,\`@```#\L#E___R@,#E
M___A-\`0```$\.,@\*@`).,0\+``),`0```#O^,0\*``)+D$`&BY!``KP%``
M``2)ITG__Z<Y``'`Y?__X@JG]``RP.7__^#56!`@`*<>`!&G=``SP.7__^$,
MIZH``;D4`!KC$/"P`"3C(/"H`"3`$```!+OC$/"X`"3`$````XWC$/"@`"2Y
M!`!HN00`*\!0```$7J=)__^G.0`!P.7__^'8N00`*Z<Y`<#`Y?__X-'L*/_)
M_WZY!``HP.7__^&9N00`.\`@```#6\#E___R%[D$`"O`Y?__^>*G]/[OXV"0
M```$IQD``.PV/+\`5:=T_RZG*0`/I_3_.,0H```KU[D4`!'C$/"@`"3C4)``
M``3C("````2Y!`!HP$````.XISD``<#E___@]*>Y``"G]/[%P!```#&[Y4P0
M````N00`)J<Y``#`Y?__X6.Y!`!B&'+L*/]-`'ZG20`"ISG_[L#E___?%D&0
M\=BY!``FN00`.:=)``;`Y?__X1N5`/'8IW0`!I5#\=FGA`$%ITD``*<Y``"Y
M!``FN10`=\#E___>^*<I`(#`Y?__WM/`$6=%(P'C$"```"3`'^_-JXGC$"`(
M`"3`'YBZW/[C$"`0`"3`$1`R5';E2"`H``#C$"`8`"3E2"`P``#`'\/2X?#E
M3"!X``#C$"`@`"2Y!`"BI_0`"[D$`#FY!``JN10`1,#E___ZW:5/@`"Y!``Y
MN00`)\#E___@QKD$`$+L(O_L`'ZY!``GP.7__]YLN00`.D&0\<2Y!`"MN00`
M*:=Y`!3`Y?__^U7C8)```)"Y!``JIYL``:>K``+`4````PJG2?__ISD``<#E
M___@[*=W_^W`$````[.2`/%8XQ#PL``D01#Q,.,0\*@`)+D$`&BY!``KP!``
M``)ZXQ#PH``DP%````-`ITG__Z<Y``'`Y?__X,FG]/[[N00`-\`@```"A\#E
M___NG>PH_R\`?.,0(```E.P8_RD`?NP8_R8P?L`0```PWN5,$````:?T_GKC
M$)`(``*GA/YLIRD``.Q!/+\`5:>$`#VG.0`/N0D`-.<#$```-Z<K`!#G```P
M`(&GA``,YP(0`$`&IRL`$.<``#``@:=T__CG0``'`"&YA`!$N2``0T$P,`&Y
MXB`CIR0`&.,B3_#_<>PL_CL#?>,R'_S_<:<(``#`(````MFR70`CIQ3__KGB
M@&&G]/XJISD`#Z?T_]&50?':IW3^^Y5#\=NG=/[WE4CQW*=T_O.51?'=IW3^
M[[D$`":G20`"ISG_QL#E___=Y[D$`":Y!``YITD`*<#E___?[L`0```#!^.0
M\*@`).,0\+``)+D$`&BY!``KI_3_6`<'!P?K?_`X`"3$N```*BFR3P"0XR"P
M```6ZYD`(``-LD\`D>/P_U#_<4&`\*32!_"HD"C`Y?__WZ*Y!`"BXR"P```6
MP.7__]^:T@`@L:"PN00`.,`@```!N<#E___MW>PH``<`?)4Q(`"GA`#/P.7_
M__3;XR"P```6P.7__]]_IUD``Z=)``'`,````G#`Y?__W<6Y!`"B["@`'P!\
MXR"P```6P.7__]]JXQ"@$``$P$````)=XS`0```$P.7__]V^XQ"@$``$XQ`0
M```$D4`0#:=T`+7C(+```!;`Y?__WTZG60`#ITD``<`P```"0\#E___=E+D$
M`*+L*``B`'RY!``XP"````%&P.7__^V%6!"P`+D$`'*Y%@`A['@`?`!\P.7_
M_]\KXQ"@$``$N00`1^,P$```!,#E___=@.,@L```%L#E___?&KD$`*+C(+``
M`!;`Y?__WQ*G20`!P#````(*P.7__]R:P$````(/N00`,KD$`"K`Y?__W6#C
M(+```!;`Y?__WOJ2`""QN00`.,`@````^L#E___M/L0K```OU[D$`++L*``<
M`'RY!``KISD!P,#E___>4>PH``D1?NP2``$`V.P2`$L!?]4'\*B0**=T`%7K
M?_#H``0'_L0H```OLL#E___Z/\0K```OL+D$`++L)O_<`'S`(````<G`Y?__
MWLN5`"`!IX3_-*?T_R_`Y?__WK+C(*`0``3$&```+Y+C("````3C,!````3`
MY?__[NFG]/^#XR"P```6P.7__]Z;XQ"@$``$XS`0```$P.7__]XRI_3_/L08
M```O<[D$`%+C,!````2Y!`!+P"````&?P.7__]Z0P.7__]XMQ%@``"\4P/3_
M_]QW!P<'!\08```G".P8`!K_?.N_\%@`)./P_V#_<<"P```F_`WAX["_^/]Q
MXQ"P```$[!;_^?]\Z[_P^``$!_X'_@<'!P?K[_!P`"3C\/]@_W'K[_$0``0'
M_@<'!P<'!P<'!P<'!^MO\#``)+D$`!^G^_]@XQ#P```DP,```">^!P?`Y?__
MX)H'!^-`\1``!.MO\-``!`?T!P<``@`!)7,O)7,`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4```O<')O8R]S96QF
M+V5X90``+W!R;V,O)6DO)7,`97AE`"X`4$%27U1%35```%!!4E]04D]'3D%-
M10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'
M`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?1TQ/0D%,7U1-4$1)
M4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@``4$%27T-,14%./0``,0!,1%],24)205)97U!!5$@`<&%R+0``+64``"TM
M``!365-414T``"4P,G@``"5S)7,E<R5S```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(``!P87)L
M```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N
M,#4T`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM
M>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C
M($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?
M<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`[
M"B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D
M(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E
M860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI
M;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;
M3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*
M<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D
M9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E
M:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T
M(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T
M.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE
M+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*
M?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A
M<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET
M92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S
M92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D
M)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?
M)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE
M86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`%5315(``%5315).04U%``!414U0
M1$E2`%1-4``O=&UP``!P97)L>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("```````1L#.P```-@````:__]^C```!2C__X#<````]/__
M@IP```$D__^9?````63__YI<```!Q/__FNP```'T__^<[````C#__YUL```"
M;/__GFP```*L__^AO````O#__Z'\```#$/__HOP```-4__^C#````VC__Z7,
M```#J/__IAP```.\__^GC````^#__ZU,```$%/__K=P```1`__^N#```!&#_
M_Z^\```$P/__L"P```3D__^Q/```!6C__[)L```%I/__L\P```7<__^];```
M!CC__[_L```&=````!0``````7I2``%X#@$;#`^@`0<.`````!0````<__]_
MX````$(``````````````!0``````7I2``%X#@$;#`^@`0```````#P````<
M__^!<```%MX`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[0!P,6Q@K/SLW,R\K)
MR,?&#J`!0@L```````!<````7/__F!````#<`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!48.P`("F`K/SLW,R\K)R,?&#J`!0@M<"L_.S<S+RLG(Q\8.H`%""TX*
MS\[-S,O*R<C'Q@Z@`4(+```````L````O/__F)````"0`$:*"HL)C`B-!XX&
MCP5*#M@#`G@*S\[-S,O*#J`!0@L````X````[/__F/````'T`$:&#H<-B`R)
M"XH*BPF,"(T'C@:/!4H.X`-R"L_.S<S+RLG(Q\8.H`%""P`````X```!*/__
MFK0```!X`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4P.R`("9,_.S<S+RLG(Q\8.
MH`$````````\```!9/__FO@```$``$:'#8@,B0N*"HL)C`B-!XX&CP5&#J`A
M3`[((@+8"L_.S<S+RLG(QPZ@`4(+````````0````:3__YNX```#1`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5.#N`"2)@5`P*F"L_.S<S+RLG(Q\;8#J`!0@L`
M```````<```!Z/__GL0````\`$R.!H\%1@[``F3/S@Z@`0```$````((__^>
MY````/0`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z@(4P.H$%,#MA"`L`*S\[-
MS,O*R<C'Q@Z@`4(+````$````DS__Y^@````!@`````````\```"8/__GYP`
M``*^`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.H"%,#O`C`GH*S\[-S,O*R<C'
MQ@Z@`4(+````$````J#__Z(<````1``````````@```"M/__HE@```%N``,!
M%HX&CP5&#L`"7,_.#J`!```````P```"V/__HZ0```6R`$:*"HL)C`B-!XX&
MCP5*#O`"`P58"L_.S<S+R@Z@`4(+````````*````PS__ZDP````C`!&BPF,
M"(T'C@:/!4H.T`)P"L_.S<S+#J`!0@L````<```#./__J90````L`$:.!H\%
M1@[``E[/S@Z@`0```%P```-8__^II````:0`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%2@[@`@)6"L_.S<S+RLG(Q\8.H`%""UH*S\[-S,O*R<C'Q@Z@`48+`P$6
MS\[-S,O*R<C'Q@Z@`0```````"````.X__^J]````&P`2HX&CP5&#L`"`EK/
MS@Z@`0```````$````/<__^K0````0H`1HD+B@J+"8P(C0>.!H\%2@[0`@)V
M"L_.S<S+RLD.H`%""P)F"L_.S<S+RLD.H`%&"P``````/```!"#__WE<```"
M3@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#N@"`P&F"L_.S<S+RLG(Q\8.H`%"
M"P```````#@```1@__^KS````3``1H8.APV(#(D+B@J+"8P(C0>.!H\%9`[`
M`@*L"L_.S<S+RLG(Q\8.H`%""P```#0```2<__^LP````50`1H@,B0N*"HL)
MC`B-!XX&CP5L#L`"`L`*S\[-S,O*R<@.H`%&"P``````6```!-3__ZWH```)
MG`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#`Z@@0)8#0]&#H"%`@,"Q@K/SLW,
MR\K)R,?&#J`!1@L#`8H*S\[-S,O*R<C'Q@Z@`4(+```````X```%,/__MRP`
M``*``$:'#8@,B0N*"HL)C`B-!XX&CP5@#M`"`P&T"L_.S<S+RLG(QPZ@`4(+
M```````0```%;/__N7`````,````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````__________\`````````````
M```````!`````````M<``````````0````````+G``````````P````````9
M*``````````-````````8E``````;__^]0````````*0``````````4`````
M```,(``````````&`````````V@`````````"@````````1;``````````L`
M````````&``````````5`````````````````````P```````+'@````````
M``(````````%*``````````4``````````<`````````%P```````!0`````
M``````<````````1J``````````(`````````E@`````````"0`````````8
M`````````!X`````````"`````!O___[``````@```$`````;____@``````
M`!$X`````&____\``````````0````!O___P````````$'P`````;___^0``
M```````.````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"P(``````````````````````````````9H@```````!G"````````&>(`
M```````:`@```````!HB````````&D(````````:8@```````!J"````````
M&J(````````:P@```````!KB````````&P(````````;(@```````!M"````
M````&V(````````;@@```````!NB````````&\(````````;X@```````!P"
M````````'"(````````<0@```````!QB````````'((````````<H@``````
M`!S"````````'.(````````=`@```````!TB````````'4(````````=8@``
M`````!V"````````':(````````=P@```````!WB````````'@(````````>
M(@```````!Y"````````'F(````````>@@```````!ZB````````'L(`````
M```>X@```````!\"````````'R(````````?0@```````!]B````````'X(`
M```````?H@```````!_"````````'^(````````@`@```````"`B````````
M($(````````@8@``````````````````````````````````````````````
M````7V``````````````````````````````````````````````````````
M``````````````````#`>```````````````````((``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#`"/____\`````````````H<``
M``````!BX```````````````````8X````````!CA````````*&T````````
M8N8```````"AO```````````````````H:0```````"AJ@``````````````
M````94Y'0T,Z("A58G5N='4@,3$N,BXP+3$V=6)U;G1U,2D@,3$N,BXP```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S
M`"YD=&]R<P`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M````````````````````````````"P````$``````````@````````(X````
M`````C@`````````#P````````````````````$``````````````!,````'
M``````````(````````"2`````````)(`````````"0`````````````````
M```$```````````````F````!P`````````"`````````FP````````";```
M```````@````````````````````!```````````````-&____8`````````
M`@````````*0`````````I``````````V`````4```````````````@`````
M`````````#X````+``````````(````````#:`````````-H````````"+@`
M```&`````@`````````(`````````!@```!&`````P`````````"````````
M#"`````````,(`````````1;`````````````````````0``````````````
M3F____\``````````@```````!!\````````$'P`````````N@````4`````
M``````````(``````````@```%MO___^``````````(````````1.```````
M`!$X`````````'`````&`````0`````````(``````````````!J````!```
M```````"````````$:@````````1J`````````)8````!0``````````````
M"``````````8````=`````0`````````0@```````!0`````````%```````
M```%*`````4````5``````````@`````````&````'X````!``````````8`
M```````9*````````!DH`````````$P````````````````````$````````
M``````!Y`````0`````````&````````&70````````9=`````````<`````
M````````````````!``````````@````A`````$`````````!@```````""`
M````````((````````!!T````````````````````!```````````````(H`
M```!``````````8```````!B4````````&)0`````````#0`````````````
M```````$``````````````"0`````0`````````"````````8H0```````!B
MA````````#]N````````````````````!```````````````F`````$`````
M`````@```````*'T````````H?0`````````W`````````````````````0`
M`````````````*8````!``````````(```````"BT````````*+0````````
M!;`````````````````````(``````````````"P`````0`````````#````
M````L`````````"P```````````0````````````````````"```````````
M````MP````$``````````P```````+`0````````L!``````````$```````
M``````````````@``````````````+X````&``````````,```````"P(```
M`````+`@`````````<`````&```````````````(`````````!````#'````
M`0`````````#````````L>````````"QX`````````)`````````````````
M````"``````````(````S`````$``````````P```````,``````````P```
M````````@`````````````````````@``````````````-(````(````````
M``,```````#`@````````,"`````````$#`````````````````````(````
M``````````#7`````0`````````P``````````````````#`@``````````F
M`````````````````````0`````````!`````0````,`````````````````
K````````````P*8`````````X`````````````````````$`````````````
